@@ -165,6 +165,7 @@ $lang = array_merge($lang, array(
 	'EMPTY_MESSAGE_SUBJECT'				=> 'Bạn phải nhập tiêu đề cho tin nhắn mà mình muốn gửi.',
 	'ENABLED'							=> 'Bật',
 	'ENCLOSURE'							=> 'Đính kèm',
+	'ENTER_USERNAME'					=> 'Nhập vào tên đăng nhập',
 	'ERR_CHANGING_DIRECTORY'			=> 'Không thể thay đổi thư mục.',
 	'ERR_CONNECTING_SERVER'				=> 'Có lỗi xảy ra trong khi kết nối đến máy chủ.',
 	'ERR_JAB_AUTH'						=> 'Không thể xác thực trên máy chủ Jabber.',
@@ -200,6 +201,7 @@ $lang = array_merge($lang, array(
 	'FORUM_RULES_LINK'		=> 'Bấm vào đây để xem nội quy của chuyên mục này',
 	'FROM'					=> 'từ',
 	'FSOCK_DISABLED'		=> 'Yêu cầu này không thể được hoàn tất bởi vì chức năng <var>fsockopen</var> đã bị vô hiệu hoặc địa chỉ của máy chủ được truy xuất trong yêu cầu không thể tìm thấy.',
+	'FSOCK_TIMEOUT'			=> 'Gặp vấn đề vượt quá thời gian quy định (Timeout) trong khi tiếp nhận thông tin.',
 
 	'FTP_FSOCK_HOST'				=> 'Địa chỉ FTP',
 	'FTP_FSOCK_HOST_EXPLAIN'		=> 'Địa chỉ máy chủ FTP được sử dụng để kết nối đến website của bạn.',
@@ -530,7 +532,7 @@ $lang = array_merge($lang, array(
 	'SEARCH_TOPIC'				=> 'Tìm kiếm trong chủ đề này…',
 	'SEARCH_UNANSWERED'			=> 'Xem bài viết chưa trả lời',
 	'SEARCH_UNREAD'				=> 'Xem bài viết chưa xem',
-	'SEARCH_USER_POSTS'			=> 'Tìm kiếm báo viết của thành viên',
+	'SEARCH_USER_POSTS'			=> 'Tìm kiếm bài viết của thành viên',
 	'SECONDS'					=> 'giây',
 	'SELECT'					=> 'Chọn',
 	'SELECT_ALL_CODE'			=> 'Chọn tất cả',
@@ -652,6 +654,10 @@ $lang = array_merge($lang, array(
 	'UNREAD_PMS'			=> '<strong>%d</strong> tin nhắn chưa xem',
 	'UNREAD_POST'			=> 'Bài viết chưa xem',
 	'UNREAD_POSTS'			=> 'Bài viết chưa xem',
+	'UNWATCH_FORUM_CONFIRM'		=> 'Bạn có chắc muốn không theo dỏi chuyên mục này?',
+	'UNWATCH_FORUM_DETAILED'	=> 'Bạn có chắc muốn không theo dỏi chuyên mục “%s”?',
+	'UNWATCH_TOPIC_CONFIRM'		=> 'Bạn có chắc muốn không theo dỏi chủ đề này?',
+	'UNWATCH_TOPIC_DETAILED'	=> 'Bạn có chắc muốn không theo dỏi chủ đề “%s”?',
 	'UNWATCHED_FORUMS'		=> 'Bạn không còn theo dõi những chuyên mục đã chọn.',
 	'UNWATCHED_TOPICS'		=> 'Bạn không còn theo dõi những chủ đề đã chọn.',
 	'UNWATCHED_FORUMS_TOPICS'	=> 'Bạn không còn theo dõi những chủ đề đã chọn.',
@@ -700,6 +706,10 @@ $lang = array_merge($lang, array(
 
 	'WARNINGS'			=> 'Cảnh cáo',
 	'WARN_USER'			=> 'Cảnh cáo thành viên',
+	'WATCH_FORUM_CONFIRM'	=> 'Bạn có chắc muốn theo dỏi chuyên mục này?',
+	'WATCH_FORUM_DETAILED'	=> 'Bạn có chắc muốn theo dỏi chuyên mục “%s”?',
+	'WATCH_TOPIC_CONFIRM'	=> 'Bạn có chắc muốn theo dỏi chủ đề này?',
+	'WATCH_TOPIC_DETAILED'	=> 'Bạn có chắc muốn theo dỏi chủ đề “%s”?',
 	'WELCOME_SUBJECT'	=> 'Chào mừng bạn đã đến với %s!',
 	'WEBSITE'			=> 'Website',
 	'WHOIS'				=> 'Tra cứu địa chỉ IP',
@@ -870,7 +880,6 @@ $lang = array_merge($lang, array(
 		'M d, \'y, H:i'		=> 'Tháng 1 01, \'07, 13:37', // Replaced 'jS' by 'd' for Vietnamese
 		'D M d, Y g:i a'	=> 'Thứ 2 Tháng 1 01, 2007 1:37 pm',
 		'F d, Y, g:i a'		=> 'Tháng một 01, 2007, 1:37 pm', // Replaced 'jS' by 'd' for Vietnamese
-		'|d M Y|, H:i'		=> 'Hôm nay, 13:37 / 01 Tháng 1 2007, 13:37',
 		'|F d, Y|, g:i a'	=> 'Hôm nay, 1:37 pm / Tháng một 01, 2007, 1:37 pm' // Replaced 'jS' by 'd' for Vietnamese
 	),
 
